==> ejc-proother-impl-3.0.0-20220329.124042-20-sources.jar: com/ejianc/business/proother/service/impl/ChangeBpmServiceImpl.java <==
package com.ejianc.business.proother.service.impl;

import com.alibaba.fastjson.JSONObject;

import com.ejianc.business.proother.bean.ChangeEntity;
import com.ejianc.business.proother.bean.ContractEntity;
import com.ejianc.business.proother.enums.ChangeStatusEnum;
import com.ejianc.business.proother.enums.DraftTypeEnum;
import com.ejianc.business.proother.enums.PerformanceStatusEnum;
import com.ejianc.business.proother.enums.SignatureStatusEnum;
import com.ejianc.business.proother.service.IChangeService;
import com.ejianc.business.proother.service.IContractService;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;

@Service("change") 
public class ChangeBpmServiceImpl implements ICommonBusinessService {

	@Autowired
	private IChangeService changeService;

	@Autowired
	private IContractService contractService;

    @Autowired
    private SessionManager sessionManager;

	private Logger logger = LoggerFactory.getLogger(this.getClass());



	/**
	 * 提交完回调
	 *
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//设置单据提交人信息
		ChangeEntity e = changeService.selectById(billId);
		UserContext userContext = sessionManager.getUserContext();

		e.setCommitDate(new Date());
		e.setCommitUserCode(userContext.getUserCode());
		e.setCommitUserName(userContext.getUserName());
		changeService.saveOrUpdate(e, false);
		return CommonResponse.success("变更回调处理完成！");
	}

	/**
	 * 终审审核前回调
	 * 1.如果单据状态不为自由态则不可提交
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		/**更新变更的审批时间  begin */
		ChangeEntity changeEntity = changeService.selectById(billId);
		logger.info("变更单终审审批前变更表数据------------->: {}", JSONObject.toJSONString(changeEntity));
		if (null != changeEntity && !(changeEntity.getBillState().equals(BillStateEnum.UNCOMMITED_STATE.getBillStateCode()) || changeEntity.getBillState().equals(BillStateEnum.UNAPPROVED.getBillStateCode()))){
			return CommonResponse.error("该单据已被修改，请勿重复提交！");
		}
		return CommonResponse.success("变更单终审审批前回调处理成功！");
	}

	/**
	 * 终审审核完回调
	 * 审批回调逻辑：
	 * 1、将现合同数据复制到合同记录表
	 * 2、将现合同附件同步到合同记录
	 * 3、将变更单据数据复制到合同表
	 * 4、将变更单附件信息同步到现合同中
	 * 5、修改合同变更状态、变更单状态
	 *
	 * @return
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		/**更新变更的审批时间  begin */
		ChangeEntity changeEntity = changeService.selectById(billId);
		//如果当前变更合同的主合同的合同状态不是履约中（冻结、解除、封账），则变更的合同不能进行提交
		ContractEntity contractEntity = contractService.selectById(changeEntity.getContractId());
		if (null != contractEntity && !contractEntity.getPerformanceStatus().equals(PerformanceStatusEnum.履约中.getCode())){
			return CommonResponse.error("当前变更合同所属的主合同状态不是履约中，该变更合同不能进行提交操作！");
		}

		Boolean commitState = false;
        if(state.equals(BillStateEnum.COMMITED_STATE.getBillStateCode())) {
			commitState = true;
            //直审设置单据提交人信息
            changeEntity.setCommitDate(new Date());
            changeEntity.setCommitUserCode(sessionManager.getUserContext().getUserCode());
            changeEntity.setCommitUserName(sessionManager.getUserContext().getUserName());
        }
        if (DraftTypeEnum.线下签订.getCode().toString().equals(changeEntity.getChangeDraftType())){
		    //调用生效回写服务
			return changeService.effectiveSaveWriteContract(billId, billTypeCode, commitState);
		}else {
			//变更单更新
			if (commitState){
				changeService.saveOrUpdate(changeEntity);
			}
			//回写主合同信息
			contractEntity.setChangeStatus(ChangeStatusEnum.变更单据审批通过.getCode());
			contractService.saveOrUpdate(contractEntity, false);
			logger.info("更新合同表数据成功,contractEntity---------->: {}", JSONObject.toJSONString(contractEntity));
		}
		return CommonResponse.success("审批回调合同成功！");
	}


	/**
	 * 有审批流的撤回前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode) {
		return doBpmBack(billId, state, billTypeCode);
	}

	/**
	 * 弃审后事件回调
	 * 回调逻辑：
	 * 1、校验变更单签章状态，若已有签章流程，则不允许撤回操作
	 * 2、将原合同附件信息删除，记录对应的附件同步至原合同
	 * 3、删除记录表、删除记录对应附件信息
	 * 4、查询对应记录表，将记录主子表数据还原到原合同中
	 * 5、将合同变更状态修改为：变更中，生效状态清空，变更单签章状态还原
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		return doBpmBack(billId, state, billTypeCode);
	}

	/**
	 * @param billId
	 * @param state
	 * @param billTypeCode
	 * @return
	 */
	@Transactional(rollbackFor = Exception.class)
	public CommonResponse<String> doBpmBack(Long billId, Integer state, String billTypeCode) {
		CommonResponse<String> resp = null;
		//提交通过、且未签章则可弃审
		ChangeEntity changeEntity = changeService.selectById(billId);

		if (!(SignatureStatusEnum.未签章.getCode().equals(changeEntity.getSignatureStatus()))){
			return CommonResponse.error("当前单据已有签章流程，不能撤回！");
		}
		changeEntity.setCommitDate(null);
		changeEntity.setCommitUserCode(null);
		changeEntity.setCommitUserName(null);
		changeService.saveOrUpdate(changeEntity);
		logger.info("撤回更新变更表数据成功,contractEntity---------->: {}", JSONObject.toJSONString(changeEntity));

		ContractEntity contractEntity = contractService.selectById(changeEntity.getContractId());
		contractEntity.setChangeStatus(ChangeStatusEnum.变更中.getCode());
		contractService.saveOrUpdate(contractEntity, false);
		logger.info("撤回更新合同表数据成功,contractEntity---------->: {}", JSONObject.toJSONString(contractEntity));

		return CommonResponse.success("执行变更单撤回回调逻辑成功！");
	}

}

==> ejc-proother-impl-3.0.0-20220429.084434-40-sources.jar: com/ejianc/business/proother/service/impl/ChangeBpmServiceImpl.java <==
package com.ejianc.business.proother.service.impl;

import com.alibaba.fastjson.JSONObject;

import com.ejianc.business.proother.bean.ChangeEntity;
import com.ejianc.business.proother.bean.ContractEntity;
import com.ejianc.business.proother.enums.ChangeStatusEnum;
import com.ejianc.business.proother.enums.DraftTypeEnum;
import com.ejianc.business.proother.enums.PerformanceStatusEnum;
import com.ejianc.business.proother.enums.SignatureStatusEnum;
import com.ejianc.business.proother.service.IChangeService;
import com.ejianc.business.proother.service.IContractService;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;

@Service("change") 
public class ChangeBpmServiceImpl implements ICommonBusinessService {

	@Autowired
	private IChangeService changeService;

	@Autowired
	private IContractService contractService;

    @Autowired
    private SessionManager sessionManager;

	private Logger logger = LoggerFactory.getLogger(this.getClass());



	/**
	 * 提交完回调
	 *
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//设置单据提交人信息
		ChangeEntity e = changeService.selectById(billId);
		UserContext userContext = sessionManager.getUserContext();

		e.setCommitDate(new Date());
		e.setCommitUserCode(userContext.getUserCode());
		e.setCommitUserName(userContext.getUserName());
		changeService.saveOrUpdate(e, false);
		return CommonResponse.success("变更回调处理完成！");
	}



	/**
	 * 终审审核完回调
	 * 审批回调逻辑：
	 * 1、将现合同数据复制到合同记录表
	 * 2、将现合同附件同步到合同记录
	 * 3、将变更单据数据复制到合同表
	 * 4、将变更单附件信息同步到现合同中
	 * 5、修改合同变更状态、变更单状态
	 *
	 * @return
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		/**更新变更的审批时间  begin */
		ChangeEntity changeEntity = changeService.selectById(billId);
		//如果当前变更合同的主合同的合同状态不是履约中（冻结、解除、封账），则变更的合同不能进行提交
		ContractEntity contractEntity = contractService.selectById(changeEntity.getContractId());
		if (null != contractEntity && !contractEntity.getPerformanceStatus().equals(PerformanceStatusEnum.履约中.getCode())){
			return CommonResponse.error("当前变更合同所属的主合同状态不是履约中，该变更合同不能进行提交操作！");
		}

		Boolean commitState = false;
        if(state.equals(BillStateEnum.COMMITED_STATE.getBillStateCode())) {
			commitState = true;
            //直审设置单据提交人信息
            changeEntity.setCommitDate(new Date());
            changeEntity.setCommitUserCode(sessionManager.getUserContext().getUserCode());
            changeEntity.setCommitUserName(sessionManager.getUserContext().getUserName());
        }
        if (DraftTypeEnum.线下签订.getCode().toString().equals(changeEntity.getChangeDraftType())){
		    //调用生效回写服务
			return changeService.effectiveSaveWriteContract(billId, billTypeCode, commitState);
		}else {
			//变更单更新
			if (commitState){
				changeService.saveOrUpdate(changeEntity);
			}
			//回写主合同信息
			contractEntity.setChangeStatus(ChangeStatusEnum.变更单据审批通过.getCode());
			contractService.saveOrUpdate(contractEntity, false);
			logger.info("更新合同表数据成功,contractEntity---------->: {}", JSONObject.toJSONString(contractEntity));
		}
		return CommonResponse.success("审批回调合同成功！");
	}


	/**
	 * 有审批流的撤回前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode) {
		return doBpmBack(billId, state, billTypeCode);
	}

	/**
	 * 弃审后事件回调
	 * 回调逻辑：
	 * 1、校验变更单签章状态，若已有签章流程，则不允许撤回操作
	 * 2、将原合同附件信息删除，记录对应的附件同步至原合同
	 * 3、删除记录表、删除记录对应附件信息
	 * 4、查询对应记录表，将记录主子表数据还原到原合同中
	 * 5、将合同变更状态修改为：变更中，生效状态清空，变更单签章状态还原
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		return doBpmBack(billId, state, billTypeCode);
	}

	/**
	 * @param billId
	 * @param state
	 * @param billTypeCode
	 * @return
	 */
	@Transactional(rollbackFor = Exception.class)
	public CommonResponse<String> doBpmBack(Long billId, Integer state, String billTypeCode) {
		CommonResponse<String> resp = null;
		//提交通过、且待签章则可弃审
		ChangeEntity changeEntity = changeService.selectById(billId);

		if (!(SignatureStatusEnum.待签章.getCode().equals(changeEntity.getSignatureStatus()))){
			return CommonResponse.error("当前单据已有签章流程，不能撤回！");
		}
		changeEntity.setCommitDate(null);
		changeEntity.setCommitUserCode(null);
		changeEntity.setCommitUserName(null);
		changeService.saveOrUpdate(changeEntity);
		logger.info("撤回更新变更表数据成功,contractEntity---------->: {}", JSONObject.toJSONString(changeEntity));

		ContractEntity contractEntity = contractService.selectById(changeEntity.getContractId());
		contractEntity.setChangeStatus(ChangeStatusEnum.变更中.getCode());
		contractService.saveOrUpdate(contractEntity, false);
		logger.info("撤回更新合同表数据成功,contractEntity---------->: {}", JSONObject.toJSONString(contractEntity));

		return CommonResponse.success("执行变更单撤回回调逻辑成功！");
	}

}
